<?php
/*-----------------------------------------------------------------------------------*/
/*	Author Widget Class
/*-----------------------------------------------------------------------------------*/

class BACKORITY_Author_Widget extends WP_Widget { 
  
  private $users_split_at = 200; //Do not run get_users() if there are more than 200 users on the website
  
  	public $defaults;
	
	function __construct() {
		$widget_ops = array( 
			'classname' => 'backority_author_widget', 
			'description' => __('نمایش لینک های فروخته شده در بکوریتی', 'backority-smart-widget'),
			'customize_selective_refresh' => true,
			'show_instance_in_rest'       => true,
		);
		$control_ops = array( 'id_base' => 'backority_author_widget' );
		parent::__construct( 'backority_author_widget', __('بکوریتی', 'backority-smart-widget'), $widget_ops, $control_ops );
		
		
		add_action( 'wp_enqueue_scripts', array($this,'enqueue_styles'));
		add_action( 'admin_enqueue_scripts', array($this,'enqueue_styles'));

		//Allow themes or plugins to modify default parameters
		$defaults = apply_filters('backority_author_widget_modify_defaults',array( 
				'title' => __('پیوند ها', 'backority-smart-widget'),
				'author' => 0,
				'auto_detect' => 0,
				'display_name' => 1,
				'display_avatar' => 1,
				'display_desc' => 1,
				'display_all_posts' => 1,
				'avatar_size' => 64,
				'name_to_title' => 0,
				'link_to_name' => 0,
				'link_to_avatar' => 0,
				'link_text' => __('', 'backority-smart-widget'),
				'link_url' => '',
				'limit_chars' => ''
			));

		$this->defaults = $defaults;
		
	}
	

	function enqueue_styles(){
 		wp_register_style( 'meks-author-widget', BRK_AUTHOR_WIDGET_URL.'css/style.css', false, BRK_AUTHOR_WIDGET_VER );
    	wp_enqueue_style( 'meks-author-widget' );
 	}

	
	function widget( $args, $instance ) {
		
		extract( $args );

		$instance = wp_parse_args( (array) $instance, $this->defaults );

		if ( is_single() && $this->is_co_authors_active() && $instance['auto_detect'] ) {
			include( $this->meks_get_template('backority-smart-widget-co-authors-template.php') );
		} else {
			include( $this->meks_get_template('backority-smart-widget-template.php') );
		}

	}
	
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['author'] = absint( $new_instance['author'] );
		$instance['auto_detect'] = !empty($new_instance['auto_detect']) ? 1 : 0;
		$instance['display_name'] = !empty($new_instance['display_name']) ? 1 : 0;
		$instance['display_avatar'] = !empty($new_instance['display_avatar']) ? 1 : 0;
		$instance['display_desc'] = !empty($new_instance['display_desc']) ? 1 : 0;
		$instance['display_all_posts'] = !empty($new_instance['display_all_posts']) ? 1 : 0;
		$instance['name_to_title'] = !empty($new_instance['name_to_title']) ? 1 : 0;
		$instance['link_to_name'] = !empty($new_instance['link_to_name']) ? 1 : 0;
		$instance['link_to_avatar'] = !empty($new_instance['link_to_avatar']) ? 1 : 0;
		$instance['link_text'] = strip_tags( $new_instance['link_text'] );
		$instance['link_url'] = !empty( $new_instance['link_url'] ) ? esc_url($new_instance['link_url']) : '';
		$instance['avatar_size'] = !empty($new_instance['avatar_size']) ? absint($new_instance['avatar_size']) : 64;
		$instance['limit_chars'] = !empty( $new_instance['limit_chars'] ) ? absint($new_instance['limit_chars']) : '';


		return $instance;
	}

	function form( $instance ) {

		$instance = wp_parse_args( (array) $instance, $this->defaults );?>

		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>">عنوان:</label>
			<input id="<?php echo $this->get_field_id( 'title' ); ?>" type="text" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo $instance['title']; ?>" class="widefat" />
		</p>

	
		
		
		
		
		
		
		<ul>
			<li>
				<label for="<?php echo $this->get_field_id( 'link_text' ); ?>">کد عضویت:</label>
				<input id="<?php echo $this->get_field_id( 'link_text' ); ?>" type="text" name="<?php echo $this->get_field_name( 'link_text' ); ?>" value="<?php echo $instance['link_text']; ?>" class="widefat"/>
				<small class="howto"><?php _e('کد اختصاصی بکوریتی را از سایت بکوریتی دریافت نمایید.'); ?></small>
			</li>
			
		</ul>

		<?php do_action('backority_widget_add_opts',$this,$instance);?>

		<?php
		
	}
	
	/* Check total number of users on the website */
	function count_users(){
		$user_count = count_users();
		if(isset($user_count['total_users']) && !empty($user_count['total_users'])){
			return $user_count['total_users'];
		}
		return 0;
	}

	private function meks_get_template($template)
	{
		$template_slug = rtrim($template, '.php');
		$template = $template_slug . '.php';

		if ($theme_file = locate_template(array('/sections/widgets/'.$template)) ) :
			$file = $theme_file;
		else :
			$file = $template;
		endif;

		return $file;
	}

	/**
	 * Support for Co-Authors Plus Plugin
	 * Check if plugin is active
	*/
	public	function is_co_authors_active() {

		if ( in_array( 'co-authors-plus/co-authors-plus.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) {
			return true;
		}
		return false;
	}


	/**
	 * Limit character description
	 * 
	 * @param string  $string Content to trim
	 * @param int     $limit  Number of characters to limit
	 * @param string  $more   Chars to append after trimmed string
	 * @return string Trimmed part of the string
	*/
	public function trim_chars( $string, $limit, $more = '...' ) {

		if ( !empty( $limit ) ) {

			$text = trim( preg_replace( "/[\n\r\t ]+/", ' ', $string ), ' ' );
			preg_match_all( '/./u', $text, $chars );
			$chars = $chars[0];
			$count = count( $chars );

			if ( $count > $limit ) {

				$chars = array_slice( $chars, 0, $limit );

				for ( $i = ( $limit -1 ); $i >= 0; $i-- ) {
					if ( in_array( $chars[$i], array( '.', ' ', '-', '?', '!' ) ) ) {
						break;
					}
				}

				$chars =  array_slice( $chars, 0, $i );
				$string = implode( '', $chars );
				$string = rtrim( $string, ".,-?!" );
				$string.= $more;
			}

		}

		return $string;
	}
	
}

?>